<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=fa
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'بازگشت به نماى كامل سايت',
	'access_mode_texte' => 'نماى ساده سايت را نمايش دهيد',
	'admin_debug' => 'رفع خرابى',
	'admin_modifier_article' => 'اصلاح اين مقاله',
	'admin_modifier_auteur' => 'اصلاح اين نويسنده',
	'admin_modifier_breve' => 'اصلاح اين خبر',
	'admin_modifier_mot' => 'اصلاح اين كليدواژه',
	'admin_modifier_rubrique' => 'اصلاح اين بخش',
	'admin_recalculer' => 'اين صفحه را نو كنيد',
	'afficher_calendrier' => 'نمايش تقويم',
	'afficher_trad' => 'ترجمه ها را نشان دهید',
	'alerte_maj_impossible' => '<b>هشدار!</b>  نو کردن داده پی  SQL برای نسخه ی   @version@ شايد بخاطر مشكل مرتبط با اصلاح پايگاه داده‌ها، غيرممكن است. با ميزبان خود تماس بگيريد.',
	'alerte_modif_info_concourante' => 'توجه: اين اطلاعات از جهات ديگر اصلاح شده مقدار واقعي اين است:',
	'analyse_xml' => 'تجزیه XML',
	'annuler' => 'باطل شود',
	'antispam_champ_vide' => 'خواهشمند است اين قسمت را خالى بگذاريد:',
	'articles_recents' => 'تازه ترين مقاله ها',
	'avis_1_erreur_saisie' => 'يك خطا در حساب شما هست، دوست داريد اطلاعات را تأييد كنيد.',
	'avis_archive_incorrect' => 'فايل بايگاني فايل اسپيپ نيست',
	'avis_archive_invalide' => 'فايل بايگانى معتبر نميباشد',
	'avis_attention' => 'توجه !',
	'avis_champ_incorrect_type_objet' => 'نام زمينه @name@براى اين نوع شئ اشتباه است@type@',
	'avis_colonne_inexistante' => 'ستون موجود  نميباشد@col@',
	'avis_erreur' => 'اشتباه : به زير مراجعه كنيد     ',
	'avis_erreur_connexion' => 'خطاى اتصال',
	'avis_erreur_cookie' => 'اشكال در كوكى',
	'avis_erreur_fonction_contexte' => 'اشتباه برنامه ريزى. اين تابع نبايد در اين متن استفاده شود',
	'avis_erreur_mysql' => 'اشتباه SQL',
	'avis_erreur_sauvegarde' => '!(@type@ @id_objet@) اشتباه در ذخيره سازى',
	'avis_erreur_visiteur' => 'مشکل ورود به قسمت خصوصی',

	// B
	'barre_a_accent_grave' => 'يک A با اکسان گراو بگذاريد',
	'barre_aide' => 'از علائم ويژه جهت صفحه آرائی استفاده نمائيد',
	'barre_e_accent_aigu' => 'يک E بزرگ با اکسان اگو بگذاريد ',
	'barre_eo' => 'يک E در O بگذاريد ',
	'barre_eo_maj' => 'يک E در O بزرگ بگذاريد',
	'barre_euro' => 'اين نماد را بگنجانيد €',
	'barre_gras' => '{{نويسه های درشت}}',
	'barre_guillemets' => ' درون « گليمه » بگذاريد',
	'barre_guillemets_simples' => ' درون گيلمه بگذاريد',
	'barre_intertitre' => 'به {{{عنوان ميان متن}}} تبديل کنيد',
	'barre_italic' => '{نويسه‌های ايتاليک}',
	'barre_lien' => '[پيوند هايپر تکست-> http://...]',
	'barre_lien_input' => 'خواهشمند است آدرس پيونديتان را يا مانند آدرسهای تارنما بصورت زيرhttp://www.mysite/comيا تنها با درج شماره مقاله اين سايت مشخص کنيد. ',
	'barre_note' => ' به [[زير نويس پائين صفحه]] تبديل شود',
	'barre_paragraphe' => 'ايجاد يك پارگراف',
	'barre_quote' => '<quote>يک پيام را بازگو کنيد</quote>',
	'bouton_changer' => 'عوض كنيد',
	'bouton_chercher' => 'جستجو كنيد',
	'bouton_choisir' => 'انتخاب كنيد',
	'bouton_deplacer' => 'حذف ',
	'bouton_download' => 'باربرداري كنيد',
	'bouton_enregistrer' => 'ثبت كنيد',
	'bouton_radio_desactiver_messagerie_interne' => 'پپام گير داخلى را غير فعال كنيد',
	'bouton_radio_envoi_annonces' => 'اعلانهاى سر مقاله ها را بفرستيد',
	'bouton_radio_non_envoi_annonces' => 'خبرها را نفرستيد',
	'bouton_radio_non_envoi_liste_nouveautes' => 'فهرست تازه ها را نفرستيد',
	'bouton_recharger_page' => 'اين صفحه را دوباره شارژ كنيد',
	'bouton_telecharger' => 'بارگذارى كنيد',
	'bouton_upload' => '>باربرداري كنيد',
	'bouton_valider' => 'معتبر كنيد',

	// C
	'cal_apresmidi' => 'بعد از ظهر',
	'cal_jour_entier' => 'تمام روز',
	'cal_matin' => 'صبح',
	'cal_par_jour' => 'روز شمار',
	'cal_par_mois' => 'ماه شمار',
	'cal_par_semaine' => 'هفته شمار',
	'choix_couleur_interface' => 'رنگ',
	'choix_interface' => 'انتخاب نمای سایت',
	'colonne' => 'ستون',
	'confirm_changer_statut' => 'توجه شما درخواست تغيير وضعيت اين كاربرد را كرده ايد آيا ميخواهيد ادامه دهيد?',
	'correcte' => 'درست',

	// D
	'date_aujourdhui' => 'امروز',
	'date_avant_jc' => 'پيش از ميلاد مسيح',
	'date_dans' => 'در عرض @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'فردا',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => ' @heure@ @jour@ ',
	'date_fmt_jour_heure_debut_fin' => ' @jour@ از @heure_debut@ تا @heure_fin@', # MODIF
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ از @heure_debut@@dtabbr@ تا @dtstart@@heure_fin@@dtend@', # MODIF
	'date_fmt_jour_mois' => '@jour@ @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@nomjour@ @date@',
	'date_fmt_periode' => 'از @date_debut@ تا @date_fin@',
	'date_fmt_periode_abbr' => ' از @dtart@@date_debut@@dtabbr@ تا@dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'از ',
	'date_fmt_periode_to' => 'تا',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'ساعت',
	'date_hier' => 'ديروز',
	'date_il_y_a' => '@delai@ پيش',
	'date_jnum1' => '1',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'يكشنبه',
	'date_jour_1_abbr' => 'يكشنبه',
	'date_jour_1_initiale' => 'يك',
	'date_jour_2' => 'دو شنبه',
	'date_jour_2_abbr' => 'دوشنبه',
	'date_jour_2_initiale' => 'دو',
	'date_jour_3' => 'سه شنبه',
	'date_jour_3_abbr' => 'سه شنبه',
	'date_jour_3_initiale' => 'سه',
	'date_jour_4' => 'چهار شنبه',
	'date_jour_4_abbr' => 'چهارشنبه',
	'date_jour_4_initiale' => 'چهار',
	'date_jour_5' => 'پنج شنبه',
	'date_jour_5_abbr' => 'پنجشنبه',
	'date_jour_5_initiale' => 'پنج',
	'date_jour_6' => 'جمعه',
	'date_jour_6_abbr' => 'جمعه',
	'date_jour_6_initiale' => 'جمعه',
	'date_jour_7' => 'شنبه',
	'date_jour_7_abbr' => 'شنبه',
	'date_jour_7_initiale' => 'شنبه',
	'date_jours' => 'روز',
	'date_minutes' => 'دقيقه',
	'date_mois' => 'ماه',
	'date_mois_1' => 'ژانويه',
	'date_mois_10' => 'اكتبر',
	'date_mois_10_abbr' => 'اكتبر',
	'date_mois_11' => 'نوامبر',
	'date_mois_11_abbr' => 'نوامبر.',
	'date_mois_12' => 'دسامبر',
	'date_mois_12_abbr' => 'دسامبر.',
	'date_mois_1_abbr' => 'ژانويه.',
	'date_mois_2' => 'فوريه',
	'date_mois_2_abbr' => 'فوريه.',
	'date_mois_3' => 'مارس',
	'date_mois_3_abbr' => 'مارس',
	'date_mois_4' => 'آوريل',
	'date_mois_4_abbr' => 'آوريل.',
	'date_mois_5' => 'مه',
	'date_mois_5_abbr' => 'مه',
	'date_mois_6' => 'ژوئن',
	'date_mois_6_abbr' => 'ژوئن',
	'date_mois_7' => 'ژوئيه',
	'date_mois_7_abbr' => 'ژوئيه.',
	'date_mois_8' => 'اوت',
	'date_mois_8_abbr' => 'اوت.',
	'date_mois_9' => 'سپتامبر',
	'date_mois_9_abbr' => 'سپتامبر.',
	'date_saison_1' => 'زمستان',
	'date_saison_2' => 'بهار',
	'date_saison_3' => 'تابستان',
	'date_saison_4' => 'پائيز',
	'date_secondes' => 'ثانيه‌ها',
	'date_semaines' => 'هفته',
	'date_un_mois' => 'ماه',
	'date_une_heure' => 'ساعت',
	'date_une_minute' => 'دقيقه',
	'date_une_seconde' => 'ثانيه',
	'date_une_semaine' => 'هفته',
	'dirs_commencer' => 'براى شروع واقعى نصب كردن',
	'dirs_preliminaire' => 'مرحله ى نخست :</b>تنظيم حق استفاده<b> ',
	'dirs_probleme_droits' => 'اشكال در حق استفاده',
	'dirs_repertoires_absents' => '<b>رپرتوارهای  زير پيدا نمی شوند:<ul>@bad_dirs@.</ul> </b>
  <p>احتمال دارد که اين مشکل از استفاده نابجای حروف بزرگ يا کوچک ناشی شده باشد. مطمئن شويد که واژه های رپرتوار با آنهايی که در بالا آمده اند مطابقت ميکنند. وگرنه شما بايد آنرا دوباره با نرم افزار FTP تان نام گذاری کنيد تا اشتباه رفع شود. سپس ميتوانيد',
	'dirs_repertoires_suivants' => '<b>شما اجازه ی نوشتن در رپرتوارها ی زیر را ندارید. <ul>@bad_dirs@.</ul> </b>
 براى دسترسی به آنها، شما بايد از مشترى اف تى پى  تان  براى اکتساب اجازه ی نوشتن به اين فهرستها استفاده كنيد. روند كار به تفضيل در راهنماى نصب بيان شده است. بمجرد اتمام كار شما ميتوانيد',
	'double_occurrence' => 'تكرار دوباره@balise@',

	// E
	'en_cours' => 'در جريان',
	'envoi_via_le_site' => 'ارسال از طريق سايت',
	'erreur' => 'اشتباه',
	'erreur_balise_non_fermee' => 'آخرین برچسب (Tag) بسته نشده:',
	'erreur_technique_ajaxform' => 'واي! يك خطاي غيرمنتظره مانع از ارايه اين فرم مي‌شود. دوباره سعي كنيد. ',
	'erreur_technique_enregistrement_champs' => 'يك خطاي فني از حق ثبت نام ميدان @champs@ جلوگيري كرده است.',
	'erreur_technique_enregistrement_impossible' => 'يك خطاي فني مانع از ثبت نام است. ',
	'erreur_texte' => 'اشتباه',
	'etape' => 'مرحله',

	// F
	'fichier_introuvable' => 'فايل @fichier@ پيدا نميشود ', # MODIF
	'form_auteur_confirmation' => 'نشاني ايميل خود را تأييد كنيد',
	'form_auteur_email_modifie' => 'نشاني ايميل شما اصلاح شده.',
	'form_auteur_envoi_mail_confirmation' => 'يك نامه‌ي الكترونيكي تأييدي به @email@ ارسال مي‌شود. شما بايد نشاني وب را كه در اين نامه براي تأييد نشاني ايميل شما ذكر شده مشاهده كنيد.  ',
	'form_auteur_mail_confirmation' => 'سلام،

شما تغيير نشاني ايميل خود را درخواست كرد‌ه‌ايد. 
براي تأييد نشاني جديد خود،‌كافي است با نشاني زير منتصل شويد (در غير اين صورت، درخواست شما ناديده گرفته مي‌شود):

     @url@
',
	'form_deja_inscrit' => '.شما قبلأ ثبت نام كرده ايد',
	'form_email_non_valide' => '.آدرس ايميلتان معتبر نميباشد',
	'form_forum_access_refuse' => '.شما ديگر اجازه ورود به اين سايت را نداريد ',
	'form_forum_bonjour' => 'سلام @nom@,',
	'form_forum_confirmer_email' => 'براي تأييد نشاني ايميل خود اين پيوند را دنبل كنيد:@url_confirm@',
	'form_forum_email_deja_enregistre' => 'اين آدرس ايميل قبلأ ثبت شده، شما ميتوانيد از كلمه ورود هميشگى تان استفاده كنيد ',
	'form_forum_identifiant_mail' => ' كلمه شناسائى جديد برايتان با ايميل فرستاده شد ',
	'form_forum_identifiants' => 'كلمه شناسايى                ',
	'form_forum_indiquer_nom_email' => 'نام و آدرس ايميلتان را در اينجا مشخص كنيد. كلمه شناساييتان بلافاصله با ايميل بدستتان خواهد رسيد',
	'form_forum_login' => ':login ',
	'form_forum_message_auto' => '(اين يك پيام خودكار است) ',
	'form_forum_pass' => 'كلمه ورود',
	'form_forum_probleme_mail' => 'اشكال در ايميل : نميتوان كلمه شناسايى را فرستاد',
	'form_forum_voici1' => 'كلمه شناسايي تان براى شركت در امور روزمره ی سایت"@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'اينهم كلمه شناسايي تان براى پيشنهاد مقالات در سايت "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'خواهشمند است آدرس ايميل تان را مشخص كنيد ',
	'form_indiquer_nom' => '.خواهشمند است نام تان را مشخص كنيد',
	'form_indiquer_nom_site' => '.خواهشمند است نام سايت تان را مشخص كنيد',
	'form_pet_deja_enregistre' => 'اين سايت قبلأ ثبت شده',
	'form_pet_signature_pasprise' => '.امضاء تان قبول نشده',
	'form_prop_confirmer_envoi' => 'تأئيد فرستادن',
	'form_prop_description' => 'توصيف/تفسير',
	'form_prop_enregistre' => 'پيشنهاد شما ثبت شد، پس از تأئيد مسئولان سايت بروى سايت خواهد رفت', # MODIF
	'form_prop_envoyer' => 'يك پيام بفرستيد',
	'form_prop_indiquer_email' => 'خواهشمند است كه يك آدرس ايميل معتبر را مشخص كنيد',
	'form_prop_indiquer_nom_site' => 'خواهشمند است نام سايت را مشخص كنيد',
	'form_prop_indiquer_sujet' => 'خواهشمند است يك موضوع را مشخص كنيد',
	'form_prop_message_envoye' => 'پيام فرستاده شده',
	'form_prop_non_enregistre' => '.پيشنهاد شما ثبت نشده است',
	'form_prop_sujet' => 'موضوع',
	'form_prop_url_site' => 'آدرس يو.آر.ال سايت',
	'forum_non_inscrit' => 'شما ثبت نشده ايد، يا اينكه آدرس يا كلمه ورودتان اشتباه است',
	'forum_par_auteur' => 'بوسيله @auteur@ ',
	'forum_titre_erreur' => '...اشتباه',

	// I
	'ical_texte_rss_articles' => 'فايل  «backend»مقالات اين سايت در آدرس زير ميباشد:',
	'ical_texte_rss_articles2' => 'شما همچنين ميتوانيد به فايلهاى«backend»مقالات هر بخش سايت درسترسى داشته باشيد:',
	'ical_texte_rss_breves' => 'همچنين سايت داراى يك فايل كه حاوى مقالات كوتاه ميباشد است. شما ميتوانيد با درج شماره بخش به مقالات كوتاه درسترسى پيدا كنيد. ',
	'icone_a_suivre' => 'دنبال كنيد    ',
	'icone_admin_site' => 'اداره سايت',
	'icone_agenda' => ' روزشمار ',
	'icone_aide_ligne' => ' كمك',
	'icone_articles' => 'مقالات',
	'icone_auteurs' => 'نويسندگان',
	'icone_brouteur' => 'شبكه نوردى سريع',
	'icone_configuration_site' => 'پيكر بندى سايت',
	'icone_configurer_site' => 'سايت تان را پيكر بندى كنيد',
	'icone_creer_nouvel_auteur' => 'يك نويسنده جديد اضافه كنيد',
	'icone_creer_rubrique' => 'يك بخش بسازيد',
	'icone_creer_sous_rubrique' => 'يك زير بخش بسازيد',
	'icone_deconnecter' => 'از اتصال به سايت خارج شويد',
	'icone_discussions' => 'گفتگو',
	'icone_doc_rubrique' => 'اسناد بخش ها',
	'icone_ecrire_article' => 'يك مقاله جديد بنويسيد',
	'icone_edition_site' => ' نشر سايت',
	'icone_gestion_langues' => 'اداره كردن بخش زبانها',
	'icone_informations_personnelles' => 'اطلاعات شخصى',
	'icone_interface_complet' => 'نماى كامل',
	'icone_interface_simple' => 'نماى ساده',
	'icone_maintenance_site' => 'تعمير و نگهدارى سايت',
	'icone_messagerie_personnelle' => 'پيك شخصى',
	'icone_repartition_debut' => 'اعلان توزيع از ابتدا',
	'icone_rubriques' => 'بخش ها',
	'icone_sauver_site' => 'ذخيره سايت',
	'icone_site_entier' => 'تمام سايت',
	'icone_sites_references' => 'سايتهاى مرجع',
	'icone_statistiques' => 'آمار سايت',
	'icone_suivi_activite' => ' پيگيرى فعاليت سايت',
	'icone_suivi_actualite' => 'تحول سايت',
	'icone_suivi_pettions' => 'پيگيرى/اداره كردن درخواست ',
	'icone_suivi_revisions' => 'اصلاح مقالات',
	'icone_supprimer_document' => 'اين سند را حذف كنيد',
	'icone_supprimer_image' => 'اين تصوير را حذف كنيد',
	'icone_tous_articles' => 'تمام مقاله هايتان',
	'icone_tous_auteur' => 'همه نويسند گان',
	'icone_tous_visiteur' => 'تمام بازديدكنندگان ',
	'icone_visiter_site' => 'بازديد از سايت همگاني',
	'icone_voir_en_ligne' => 'بر روى تارنما ببينيد',
	'img_indisponible' => 'تصوير موجود نيست',
	'impossible' => 'ناممکن',
	'info_a_suivre' => 'دنباله دار »',
	'info_acces_interdit' => 'حق استفاده ممنوع',
	'info_acces_refuse' => 'حق استفاده پذيرفته نشده',
	'info_action' => 'حركت : @action@',
	'info_administrer_rubriques' => 'شما ميتوانيد اين بخش و زير بخشهايش را اداره كنيد',
	'info_adresse_non_indiquee' => 'شما هيچ آدرسى را براى آزمايش مشخص نكرده ايد ',
	'info_aide' => ':كمك',
	'info_ajouter_mot' => 'اين واژه را اضافه كنيد',
	'info_annonce' => 'خبر',
	'info_annonces_generales' => ': خبر هاى كلى',
	'info_article_propose' => 'مقاله پيشنهادى',
	'info_article_publie' => 'مقاله منتشر شده',
	'info_article_redaction' => 'مقاله در حال نگارش',
	'info_article_refuse' => 'مقاله ى پذيرفته نشده',
	'info_article_supprime' => 'مقاله حذف شده',
	'info_articles' => 'مقالات',
	'info_articles_a_valider' => 'مقالات براى تأئيد شدن ',
	'info_articles_nb' => '@nb@ مقالات',
	'info_articles_proposes' => 'مقالات پيشنهادى',
	'info_articles_un' => 'مقاله 1',
	'info_auteurs_nombre' => ': نويسنده',
	'info_authentification_ftp' => '(FTP) تأئيد وب مستر بوسيله  ',
	'info_breves_2' => 'مقاله كوتاه',
	'info_breves_nb' => '@nb@ خبر',
	'info_breves_un' => 'خبر 1',
	'info_connexion_refusee' => 'ارتباط پذيرفته نشد',
	'info_contact_developpeur' => '.خواهشمند است كه با يك برنامه نويس تماس بگيريد', # MODIF
	'info_contenance' => ': اين سايت حاوى',
	'info_contribution' => 'نوشته‌ها',
	'info_copyright' => '@spip@ يك نرم افزار آزاد است  كه @lien_gpl@ توزيع شده.',
	'info_copyright_doc' => ' براى اطلاعات بيشتر مراجعه كنيد به سايت <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'با مجوز GPL ',
	'info_cours_edition' => 'مقاله در حال نگارش', # MODIF
	'info_creer_repertoire' => 'خواهشمند است كه يك فايل يا يك فهرست بنام  بسازيد: ',
	'info_creer_repertoire_2' => 'در داخل زير بخش <b>@repertoire@</b> سپس :',
	'info_creer_vignette' => 'ساخت خودكار تصاوير كوچك',
	'info_creerdansrubrique_non_autorise' => 'شما حقوق كافي براي ايجاد مطلب در اين بخش را نداريد',
	'info_deplier' => 'باز كنيد',
	'info_descriptif_nombre' => ': توصيف',
	'info_description' => ': توصيف',
	'info_description_2' => ': توصيف',
	'info_dimension' => ': ابعاد',
	'info_documents_nb' => '@nb@ سندها',
	'info_documents_un' => 'سند 1',
	'info_ecire_message_prive' => 'يك پيام خصوصى بنويسيد',
	'info_email_invalide' => 'آدرس ايميل معتبر نميباشد',
	'info_en_cours_validation' => 'مقاله هايتان در حال نگارش',
	'info_en_ligne' => ': هم اكنون در سايت ميباشد',
	'info_envoyer_message_prive' => 'يك پيام خصوصى براى اين نويسنده بفرستيد',
	'info_erreur_requete' => ': اشتباه در درخواست',
	'info_erreur_squelette2' => 'هيچ اسكلتي <b>@fichier@</b>در دسترس نميباشد',
	'info_erreur_systeme' => 'اشتباه در سيستم(errno @errsys@)',
	'info_erreur_systeme2' => 'شايد هارد ديسك پر شده باشد، يا پايگاه داده‌ها آسيب ديده باشد<br />
<span style="color:red;">سعي كنيد <a href=\'@script@\'>پايگاه داده‌ها را تعمير كنيد base</a>, يا با ميزبان خود تماس بگيريد.</span>',
	'info_fini' => 'پايان!',
	'info_format_image' => 'اندازه هاى تصاويرى كه ميتوانند براى ساختن همان تصاوير ولى بصورت كوچك مورد استفاده قرار بگيرند: @gd_formats@.',
	'info_format_non_defini' => 'اندازه مشخص نشده',
	'info_grand_ecran' => 'صفحه بزرگ',
	'info_image_aide' => 'كمك',
	'info_image_process_titre' => 'شيوه ى درست كردن تصاوير كوچك',
	'info_impossible_lire_page' => '<b>اشتباه !</b> خواندن صفحه <tt><html>@test_proxy@</html></tt> با پروكسى غير ممكن ميباشد',
	'info_installation_systeme_publication' => '...استقرار سيستم نشر',
	'info_installer_documents' => 'شما ميتوانيد بطور خودكار تمام مطالب پرونده را نصب كنيد @upload@.',
	'info_installer_ftp' => 'بعنوان گرداننده سايت، شما ميتوانيد فايلهاى درون پرونده @upload@ را مستقر كنيد سپس آنها را مستقيمأ در اينجا انتخاب كنيد. ', # MODIF
	'info_installer_images' => ': شما ميتوانيد اين نوع تصاوير را نصب كنيدJPEG, GIF, PNG',
	'info_installer_images_dossier' => 'تصاوير درون پرونده @upload@  را مستقر كنيد  تا بتوانيد آنها را مستقيمأ در اينجا انتخاب كنيد. ',
	'info_interface_complete' => 'نماى كامل',
	'info_interface_simple' => 'نماى ساده ',
	'info_joindre_document_article' => '                                                                                      شما ميتوانيد به اين مقاله مطالبى  يا اسنادى بيفزائيد                                         ',
	'info_joindre_document_rubrique' => 'شما ميتوانيد در اين بخش اسنادى را اضافه كنيد',
	'info_joindre_documents_article' => ': شما ميتوانيد به اين مقاله اسنادى را اضافه كنيد',
	'info_l_article' => 'مقاله',
	'info_la_breve' => 'مقاله كوتاه',
	'info_la_rubrique' => 'بخش',
	'info_langue_principale' => 'زبان اصلى سايت',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ pixels',
	'info_les_auteurs_1' => '@les_auteurs@ نوشته',
	'info_logo_format_interdit' => 'فقط لوگوهاى زير @formats@ قابل استفاده اند',
	'info_logo_max_poids' => 'لوگوها بايد حتما كمتر از @maxi@ باشند   (اين فايل @actuel@ است).',
	'info_mail_fournisseur' => 'شما@fournisseur.com',
	'info_message_2' => 'پيام',
	'info_message_supprime' => 'پيام حذف شده',
	'info_messages_nb' => '@nb@ پيام‌ها',
	'info_messages_un' => 'پيام 1',
	'info_mise_en_ligne' => ': تاريخ راه اندازى',
	'info_modification_parametres_securite' => 'اصلاح پارامترهاى ايمنى',
	'info_mois_courant' => ':در ماه جارى',
	'info_mot_cle_ajoute' => 'كليد-واژه بعدى اضافه شده به',
	'info_multi_herit' => ' زبان اصلی',
	'info_multi_langues_soulignees' => '<u>زبان‌هاي مشخص شده</u> ترجمه تمام يا بخشي از متن‌هاي نرم‌افزار واسط را ارايه مي‌دهد. اگر اين زبان‌ها را انتخاب كنيد، بعضي از عناصر سايت عمومي (تاريخ‌ها، فرم‌ها) به صورت خود به خودي ترجمه مي‌شود. براي زبان‌هايي كه مشخص نشده‌اند، اين عناصر باز زبان پيش‌گزيده سايت نمايش داده مي‌شوند. ',
	'info_multilinguisme' => 'چند زبانه گى',
	'info_nom_non_utilisateurs_connectes' => 'نامتان در فهرست كاربران متصل به تارنما نميباشد', # MODIF
	'info_nom_utilisateurs_connectes' => 'نامتان در فهرست كاربران متصل به تارنما ميباشد', # MODIF
	'info_nombre_en_ligne' => ': هم اكنون روى خط',
	'info_non_resultat' => '"@cherche_mot@" بى نتيجه براى   ',
	'info_non_utilisation_messagerie' => 'شما از پيامگير داخلى سايت استفاده نميكنيد.',
	'info_nouveau_message' => 'شما يك پيام جديد داريد',
	'info_nouveaux_messages' => 'پيام جديد داريد @total_messages@ شما',
	'info_numero_abbreviation' => 'شماره ',
	'info_obligatoire' => 'اين اطلاعات اجباري است',
	'info_pense_bete' => 'يادداشت',
	'info_petit_ecran' => 'صفحه كوچك',
	'info_petition_close' => 'درخواست بسته',
	'info_pixels' => 'پيكسل',
	'info_plusieurs_mots_trouves' => 'پيدا شده"@cherche_mot@":چندين واژه-كليد براى',
	'info_portfolio_automatique' => ': تصاوير را بطور خودكار در صفحه اى گذاشتن',
	'info_premier_resultat' => '[@total@ نتيجه اول از مجموع@debut_limit@]',
	'info_premier_resultat_sur' => '[@total@نتيجه اول از مجموع @debut_limit@]',
	'info_propose_1' => ' @titre@ :[@nom_site_spip@] را پيشنهاد ميكند',
	'info_propose_2' => '
مقاله پيشنهاد شده---------------',
	'info_propose_3' => 'براى انتشار پيشنهاد شده "@titre@" مقاله',
	'info_propose_4' => 'خواهشمند است اين را بخوانيد و نظرتان را بدهيد',
	'info_propose_5' => '. سخنگاهى كه به آن وصل است : در اين آدرس موجود ميباشد',
	'info_publie_01' => 'مقاله "@titre@" بوسيله @connect_nom@    معتبر گرديد.',
	'info_publie_1' => '[@nom_site_spip@]منتشر ميكند : @titre@',
	'info_publie_2' => 'مقاله منتشر شده
--------------',
	'info_rechercher' => 'جستجو ',
	'info_rechercher_02' => 'جستجو:',
	'info_remplacer_vignette' => ': علامت گرافيكى شخصى (لوگو ) را جايگزين تصوير كنيد',
	'info_rubriques_nb' => '@nb@ بخش‌ها',
	'info_rubriques_un' => 'بخش 1',
	'info_sans_titre_2' => 'بدون عنوان',
	'info_selectionner_fichier' => 'شما ميتوانيد يك فايل از پرونده @upload@ انتخاب كنيد',
	'info_selectionner_fichier_2' => ': يك فايل انتخاب كنيد',
	'info_sites_nb' => '@nb@ سايت‌ها',
	'info_sites_un' => 'سايت 1',
	'info_supprimer_vignette' => 'تصاوير كوچك را حذف كنيد',
	'info_symbole_bleu' => 'نماد آبى نمايانگر يادداشت است : يا بعبارتى پيام، براى استفاده شخصى.',
	'info_symbole_jaune' => 'نماد زرد نشانگر یک خبر براى تمام نويسندگان ميباشد : كه قابل اصلاح توسط تمام گردانندگان سايت و قابل رؤيت براى تمام نويسندگان ميباشد.', # MODIF
	'info_symbole_vert' => 'نماد سبز نشانگر پيامهاى رد و بدل شده با ديگر كاربران ميباشد.', # MODIF
	'info_telecharger_nouveau_logo' => ':يك لوگوى جديد بارگذارى كنيد',
	'info_telecharger_ordinateur' => ':با رايانه خودتان بارگذارى كنيد',
	'info_tous_resultats_enregistres' => '[تمام نتايج ثبت شده اند]',
	'info_tout_afficher' => 'همه را نمايش دهيد',
	'info_travaux_texte' => 'اين سايت هنوز پيكر بندى نشده. كمى ديرتر بازگرديد',
	'info_travaux_titre' => 'سايت در حال بازساى',
	'info_trop_resultat' => ';"@cherche_mot@"ازدياد جواب براى جستجوى خواهشمند است، جستجو را دقيقتر كنيد',
	'info_utilisation_messagerie_interne' => 'شما از پيام گير داخلى اين سايت استفاده ميكنيد',
	'info_valider_lien' => 'اين پيوند را معتبر كنيد',
	'info_verifier_image' => 'خواهشمند است انتقال صحيح تصاوير را بازرسى كنيد ',
	'info_vignette_defaut' => 'تصاوير كوچك قبل از شكل بندى',
	'info_vignette_personnalisee' => 'تصاوير كوچك پس از شكل بندى',
	'info_visite' => ':بازديد',
	'info_vos_rendez_vous' => 'ملاقات هاى آيندتان',
	'infos_vos_pense_bete' => 'يادداشت هايتان',

	// L
	'label_ajout_id_rapide' => 'افزودن سريع',
	'label_poids_fichier' => 'اندازه',
	'lien_afficher_icones_seuls' => 'فقط آيكونها را نشان دهيد',
	'lien_afficher_texte_icones' => 'آيكونها و متن را نشان دهيد',
	'lien_afficher_texte_seul' => 'فقط متن را نشان دهيد',
	'lien_liberer' => 'آزاد كنيد',
	'lien_liberer_tous' => 'نشر مقالات',
	'lien_nouvea_pense_bete' => 'يادداشت جديد',
	'lien_nouveau_message' => 'پيام جديد',
	'lien_nouvelle_annonce' => 'خبر جديد',
	'lien_petitions' => 'درخواست',
	'lien_popularite' => '@popularite@% : محبوبيت سايت',
	'lien_racine_site' => 'ريشه سايت',
	'lien_reessayer' => 'دوباره آزمايش كنيد',
	'lien_repondre_message' => 'پاسخ به اين پيام',
	'lien_supprimer' => 'حذف كنيد',
	'lien_tout_afficher' => 'همه را نشان دهيد',
	'lien_visite_site' => 'از اين سايت ديدن كنيد',
	'lien_visites' => 'بازديد @visites@',
	'lien_voir_auteur' => 'اين نويسنده را ببينيد',
	'ligne' => 'خط',
	'login' => 'ارتباط',
	'login_acces_prive' => 'دسترسى به قسمت خصوصى',
	'login_autre_identifiant' => 'با يك كلمه شناسايى ديگر متصل شويد',
	'login_cookie_accepte' => 'خواهشمند است كه مرورگر تان را بشيوه اى تنظيم كنيد كه آنها را بپذيرد ( دست كم براى اين سايت)',
	'login_cookie_oblige' => ' شما بايد كوكى ها cookies را براى امنيت بيشتر براى شناساييتان بپذيريد',
	'login_deconnexion_ok' => 'ارتباط قطع شد',
	'login_erreur_pass' => 'كلمه ورود اشتباه است',
	'login_espace_prive' => 'قسمت شخصي',
	'login_identifiant_inconnu' => '« @login@ » كلمه شناسايى ناشناس است ',
	'login_login' => ': Login ',
	'login_login2' => 'لاگين يا نشاني ايميل :',
	'login_login_pass_incorrect' => '(يا كلمه شناسايى اشتباه است Login)',
	'login_motpasseoublie' => 'آيا كلمه ورود را فراموش كرديد؟',
	'login_non_securise' => ' توجه ! اين پرسشنامه ايمن نميباشد. اگر ميخواهيد كه كلمه ورودى تان روى شبكه توسط ديگران ديده نشود، خواهشمند است جاوا اسكريپت را بروى مرورگر تان فعال نمائيد',
	'login_nouvelle_tentative' => 'كوششى ديگر',
	'login_par_ici' => 'شما در اينجا ... ثبت شديد ...',
	'login_pass2' => 'كلمه ورود :',
	'login_preferez_refuser' => 'اگر نخواهيد كوكى ها cookies را قبول كنيد، شيوه ى ديگرى (با امنيت كمتر) در دسترستان ميباشد:',
	'login_recharger' => 'اين صفحه را دوباره شارژ كنيد',
	'login_rester_identifie' => 'برای چند روز معتبر کنيد', # MODIF
	'login_retour_public' => 'بازگشت به سايت همگانى',
	'login_retour_site' => 'بازگشت به سايت همگانى',
	'login_retoursitepublic' => 'بازگشت به سايت همگانى',
	'login_securise' => 'لاگين امن ',
	'login_sinscrire' => 'ثبت نام ', # MODIF
	'login_test_navigateur' => 'آزمايش مرورگر/ ارتباط دوباره',
	'login_verifiez_navigateur' => '(...مطمئن شويد كه مرورگر كلمه ورودى تان را ضبط نكرده است)',

	// M
	'masquer_colonne' => 'پنهان كردن اين ستون',
	'masquer_trad' => 'ترجمه ها را پنهان کنید',
	'module_fichiers_langues' => 'فايل هاى زبان',

	// N
	'navigateur_pas_redirige' => 'اگر مرورگر تان دوباره هدايت نشد, اينجا را براى ادامه كليك كنيد.',
	'numero' => 'شماره',

	// O
	'occurence' => 'واقعه',
	'onglet_affacer_base' => 'پاك كردن پايگاه',
	'onglet_auteur' => 'نويسنده',
	'onglet_contenu_site' => 'محتوى سايت',
	'onglet_evolution_visite_mod' => 'تحول بازديدها',
	'onglet_fonctions_avances' => 'عملكرد پيشرفته',
	'onglet_informations_personnelles' => 'اطلاعات شخصى',
	'onglet_interactivite' => 'تبادل كاربر-سايت',
	'onglet_messagerie' => 'پيام گير',
	'onglet_repartition_rubrique' => 'نمودار توزيع براى هر بخش',
	'onglet_save_restaur_base' => 'ذخيره / بازسازى پايگاه',
	'onglet_vider_cache' => 'خالى كردن فايل موقت',

	// P
	'pass_choix_pass' => 'خواهشمند است كلمه ورودى جديدتان را انتخاب كنيد',
	'pass_erreur' => 'اشتباه',
	'pass_erreur_acces_refuse' => '<b>اشتباه :</b>شما به اين سايت ديگر دسترسى نداريد',
	'pass_erreur_code_inconnu' => '<b>اشتباه :</b> اين كد به هيچيك از بازديدكنندگانى كه به اين سايت دسترسى دارند تعلق ندارد', # MODIF
	'pass_erreur_non_enregistre' => '<b>اشتباه :</b>اين آدرس در اين سايت ثبت نشده است<tt>@email_oubli@</tt> ',
	'pass_erreur_non_valide' => '<b>اشتباه :</b>  اين ايميل معتبر نميباشد<tt>@email_oubli@</tt> ',
	'pass_erreur_probleme_technique' => '<b>اشتباه :</b>بخاطر مشكل فنى نميتوان ايميل را فرستاد',
	'pass_espace_prive_bla' => 'قسمت خصوصى اين سايت پس از ثبت نام بروى بازديدكنندگان بازخواهد بود. شما ميتوانيد پس از ثبت نام، مقالات در حال نگارش را بخوانيد، همچنين ميتوانيد پيشنهاد مقاله و يا در تمام سخنگاه ها شركت كنيد ', # MODIF
	'pass_forum_bla' => 'شما درخواست شركت در سخنگاه مختص بازديدكنندگان ثبت شده را كرديد', # MODIF
	'pass_indiquez_cidessous' => 'آدرس ايميلى كه با آن ثبت شده ايد را مشخص كنيد. شما ايميلى دريافت خواهيد كرد كه شامل راهنماى ورودتان ميباشد',
	'pass_mail_passcookie' => 'اين يك پيام خودكار است.براى دسترسى به سايت@nom_site_spip@ (@adresse_site@)خواهشمند است به اين آدرس مراجعه كنيد :  @sendcookie@
شما ميتوانيد كلمه ورودى ديگرى را وارد كنيد و دوباره به سايت وصل شويد', # MODIF
	'pass_mot_oublie' => 'كلمه ورود فراموش شده',
	'pass_nouveau_enregistre' => 'كلمه ورودى جديدتان ثبت شد.',
	'pass_nouveau_pass' => 'كلمه ورودى جديد',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'فراموشى كلمه ورودى ',
	'pass_procedure_changer' => 'براي تغيير گذرواژه‌ي خود، ما بايد اول شما را شناسايي كنيم. براي اين كار نشاني ايميل مربوط به حساب خود را به ما اعلام كنيد. ', # MODIF
	'pass_quitter_fenetre' => 'اين پنجره را ترك كنيد',
	'pass_rappel_login' => '(login)شما : « @login@ ».',
	'pass_recevoir_mail' => ' شما ايميلى دريافت خواهيد كرد كه شامل راهنماى ورودتان به سايت ميباشد', # MODIF
	'pass_retour_public' => 'بازگشت به سايت همگانى',
	'pass_rien_a_faire_ici' => 'شما اينجا كارى نداريد',
	'pass_vousinscrire' => 'ثبت نام شما در اين سايت',
	'precedent' => 'پيشين',
	'previsualisation' => 'پيش بازديد',
	'previsualiser' => 'پيش بازبينى',

	// R
	'retour' => 'بازگشت',

	// S
	'spip_conforme_dtd' => 'این سند با DOCTYPE اسپیپ مطابقت میکند:',
	'squelette' => 'اسکلت',
	'squelette_inclus_ligne' => 'اسکلت گنجانده شده, خط',
	'squelette_ligne' => 'اسکلت, خط',
	'stats_visites_et_popularite' => '@visites@ بازديد; محبوبيت: @popularite@',
	'suivant' => 'بعدى',

	// T
	'taille_go' => '@taille@ برو',
	'taille_ko' => '@taille@ kb',
	'taille_mo' => '@taille@ Mb',
	'taille_octets' => '@taille@ bits',
	'taille_octets_bi' => '@taille@ bits',
	'texte_actualite_site_1' => 'هنگاميكه با نماى سايت بيشتر آشنا شديد ميتوانيد روى ',
	'texte_actualite_site_2' => 'نماى كامل',
	'texte_actualite_site_3' => 'براى امكانات بيشتر.',
	'texte_creation_automatique_vignette' => 'ساخت خودكار تصاوير كوچك در اين سايت فعال است. اگر از اين دستورالعمل ،تصاوير با ابعاد @gd_formats@ را مستقر كنيد، آنها همراه تصاوير كوچك با اندازه حداكثر@taille_preview@پيكسل خواهند بود',
	'texte_documents_associes' => 'اسناد بعدى به مقاله پيوند زده شده اند و بطور مستقيم گنجانده نشده اند. بنابر صفحه بندى سايت آنها ميتوانند بصورت اسناد پيوسته ظاهر شوند.',
	'texte_erreur_mise_niveau_base' => 'اشتباه در پایگاه داده‌ها بهنگام تنظیم. تصوير <b>@fichier@</b> منتقل نشده است   (مقاله @id_article@).
اين شماره را بدقت يادداشت,و سعى كنيد عمل را تکرار کنید، و مطمئن شوید که تصاوير در مقالات ظاهر ميشوند.',
	'texte_erreur_visiteur' => 'شما سعی کردید با login که امکان دسترسی به قسمت خصوصی را نمیدهد وارد شوید.',
	'texte_inc_auth_1' => ' شما با اين لاگين شناسايى مي‌شويد :
  login <b>@auth_login@</b>,اما اين نام ديگر در پايگاه وجود ندارد.
',
	'texte_inc_auth_2' => 'دوباره متصل شويد',
	'texte_inc_auth_3' => 'پس از ترك و راه انداختن مجدد مرورگر. ',
	'texte_inc_config' => 'تغيير در اين صفحات در عملكرد سايتتان تاثير قابل توجهى بجاى ميگذارد. بشما پيشنهاد ميكنيم اگر با سيستم اسپيپ آشنايى نداريد از  دستكارى آنها بپرهيزيد.<br /><br /><b> توصيه ميشود كه اين وظيفه را به وب مستر اصلى محول كنيد.</b>',
	'texte_inc_meta_1' => 'سيستم بهنگام نوشتن فايل<code>@fichier@</code> به مشكلى برخورد كرده است, خواهشمند است، بعنوان گرداننده سايت', # MODIF
	'texte_inc_meta_2' => 'حق استفاده را تاييد كنيد',
	'texte_inc_meta_3' => 'در رپرتوار<code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'در حال نگارش',
	'texte_statut_poubelle' => 'در سطل آشغال',
	'texte_statut_propose_evaluation' => 'براى ارزيابى پيشنهاد شده',
	'texte_statut_publie' => 'برروى تارنما منتشر شود',
	'texte_statut_refuse' => 'پذيرفته نشده',
	'titre_ajouter_mot_cle' => 'يك كليد-واژه اضافه كنيد :',
	'titre_cadre_raccourcis' => 'راه كوتاه :',
	'titre_changer_couleur_interface' => 'رنگ نماى سايت را تغيير دهيد',
	'titre_image_admin_article' => 'شما ميتوانيد اين مقاله را اداره كنيد',
	'titre_image_administrateur' => 'گرداننده سايت', # MODIF
	'titre_image_aide' => 'كمك براى اين قسمت',
	'titre_image_auteur_supprime' => 'نويسنده حذف شده',
	'titre_image_redacteur' => 'نويسنده بدون حق دسترسى',
	'titre_image_redacteur_02' => 'نويسنده',
	'titre_image_selecteur' => 'نشان دادن ليست',
	'titre_image_visiteur' => 'بازديد كننده',
	'titre_joindre_document' => 'يك سند اضافه كنيد',
	'titre_mots_cles' => 'واژه-كليدها',
	'titre_probleme_technique' => ' توجه : يك مشكل فنى (serveur SQL)از دسترسى به اين قسمت سايت جلوگيرى ميكند. از توجه تان متشكريم',
	'titre_publier_document' => 'در اين بخش يك سند منتشر كنيد',
	'titre_signatures_attente' => 'امضاء‌ها در انتظار تأييد',
	'titre_signatures_confirmees' => 'امضاء‌ها تأييد شده',
	'titre_statistiques' => 'آمار سايت',
	'titre_titre_document' => 'عنوان سند :',
	'todo' => 'آتي',
	'trad_reference' => 'مرججع ترجمه‌ها',

	// Z
	'zbug_balise_b_aval' => 'تگ B در پايين',
	'zbug_balise_inexistante' => 'تگ @balise@ به خاطر @form@ بد اعلام شده',
	'zbug_balise_sans_argument' => 'شناسه (آرگومان) فاقد در تگ @balise@',
	'zbug_boucle' => 'حلقه',
	'zbug_boucle_recursive_undef' => 'حلقه بازگشتى نامشخص',
	'zbug_calcul' => 'شمارش',
	'zbug_champ_hors_boucle' => '@champ@ بيرون از حلقه',
	'zbug_champ_hors_motif' => 'ميدان @champ@ بيرون از حلقه @motif@ ',
	'zbug_code' => 'كد',
	'zbug_critere_inconnu' => 'معيار ناشناس @critere@',
	'zbug_distant_interdit' => 'ممنوع خارجي',
	'zbug_doublon_table_sans_cle_primaire' => 'بدون كليد مقدماتي خودكار دوبرابر كردن از طريق يك جدول(؟)',
	'zbug_doublon_table_sans_index' => 'بدون اندكس در جدول تکرار شود',
	'zbug_erreur_boucle_double' => 'توصيف دوگانه‌ي حلقه‌ي @id@',
	'zbug_erreur_boucle_fermant' => 'حلقه @id@ بسته نشد',
	'zbug_erreur_boucle_syntaxe' => 'نحو حلقه‌ي @id@ درست نيست ',
	'zbug_erreur_compilation' => 'اشتباه در کامپایل ',
	'zbug_erreur_execution_page' => 'اشتباه در اجراى برنامه ى صفحه',
	'zbug_erreur_filtre' => 'فيلتر @filtre@ تعريف نشده',
	'zbug_erreur_meme_parent' => 'معيار {meme_parent} تنها براى حلقه هاى (FORUMS) يا (RUBRIQUES) ميباشد',
	'zbug_erreur_squelette' => 'اشتباه در ساختار اسكلت',
	'zbug_hors_compilation' => 'تأليف خارجي',
	'zbug_info_erreur_squelette' => 'اشتباه در سايت',
	'zbug_inversion_ordre_inexistant' => 'وارانگى ترتيب  ناموجود',
	'zbug_pagination_sans_critere' => 'تگ  PAGINATION# بدون معيار {pagination} یا استفاده شده در یک حلقه',
	'zbug_parametres_inclus_incorrects' => ' پارامتر گنجانده‌شده نادرست:@param@ ',
	'zbug_profile' => 'زمان محاسب:@time@',
	'zbug_resultat' => 'نتيجه',
	'zbug_serveur_indefini' => ' سرور SQL مشخص نيست',
	'zbug_statistiques' => 'آمارهاي درخواست‌هاي SQL طبقه‌بندي شده براساس مدت ',
	'zbug_table_inconnue' => 'جدول SQL « @table@ »  ناشناخته است',
	'zxml_connus_attributs' => 'مشخصات شناخته شده',
	'zxml_de' => 'از',
	'zxml_inconnu_attribut' => 'مشخصه ی ناشناخته',
	'zxml_inconnu_balise' => 'TAG ناشناخته',
	'zxml_inconnu_entite' => 'ناشناخته',
	'zxml_inconnu_id' => 'ID ناشناخته',
	'zxml_mais_de' => 'اما از',
	'zxml_non_conforme' => 'با موضوع مطابق نیست',
	'zxml_non_fils' => 'پسرش نیست',
	'zxml_nonvide_balise' => 'TAG خالی نیست',
	'zxml_obligatoire_attribut' => 'مشخصه اجباری اما غایب در',
	'zxml_succession_fils_incorrecte' => 'جانشین پسر درست نمیباشد',
	'zxml_survoler' => 'برای دیدن جوابهای صحیح نوک فلش را روی آنها بگذارید',
	'zxml_valeur_attribut' => 'ارزش مشخصه ها',
	'zxml_vide_balise' => 'TAG خالی',
	'zxml_vu' => 'قبلأ دیده شده',
];
